@@ -1,52 +1,78 @@
-( cd opt/kde/share/doc/HTML/en/irkick ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/irkick ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/okteta ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/okteta ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/lib ; rm -rf libkerfuffle.so.4 )
+( cd opt/kde/lib ; ln -sf libkerfuffle.so.4.4.0 libkerfuffle.so.4 )
+( cd opt/kde/lib ; rm -rf libkerfuffle.so )
+( cd opt/kde/lib ; ln -sf libkerfuffle.so.4 libkerfuffle.so )
+( cd opt/kde/lib ; rm -rf libkdelirc_shared.so.1 )
+( cd opt/kde/lib ; ln -sf libkdelirc_shared.so.1.0.0 libkdelirc_shared.so.1 )
+( cd opt/kde/lib ; rm -rf libkdelirc_shared.so )
+( cd opt/kde/lib ; ln -sf libkdelirc_shared.so.1 libkdelirc_shared.so )
+( cd opt/kde/lib ; rm -rf libkastencore.so.4 )
+( cd opt/kde/lib ; ln -sf libkastencore.so.4.4.0 libkastencore.so.4 )
+( cd opt/kde/lib ; rm -rf libkastencore.so )
+( cd opt/kde/lib ; ln -sf libkastencore.so.4 libkastencore.so )
+( cd opt/kde/lib ; rm -rf libkastengui.so.4 )
+( cd opt/kde/lib ; ln -sf libkastengui.so.4.4.0 libkastengui.so.4 )
+( cd opt/kde/lib ; rm -rf libkastengui.so )
+( cd opt/kde/lib ; ln -sf libkastengui.so.4 libkastengui.so )
+( cd opt/kde/lib ; rm -rf libkastencontrollers.so.4 )
+( cd opt/kde/lib ; ln -sf libkastencontrollers.so.4.4.0 libkastencontrollers.so.4 )
+( cd opt/kde/lib ; rm -rf libkastencontrollers.so )
+( cd opt/kde/lib ; ln -sf libkastencontrollers.so.4 libkastencontrollers.so )
+( cd opt/kde/lib ; rm -rf liboktetacore.so.4 )
+( cd opt/kde/lib ; ln -sf liboktetacore.so.4.4.0 liboktetacore.so.4 )
+( cd opt/kde/lib ; rm -rf liboktetacore.so )
+( cd opt/kde/lib ; ln -sf liboktetacore.so.4 liboktetacore.so )
+( cd opt/kde/lib ; rm -rf liboktetagui.so.4 )
+( cd opt/kde/lib ; ln -sf liboktetagui.so.4.4.0 liboktetagui.so.4 )
+( cd opt/kde/lib ; rm -rf liboktetagui.so )
+( cd opt/kde/lib ; ln -sf liboktetagui.so.4 liboktetagui.so )
+( cd opt/kde/lib ; rm -rf liboktetakastencore.so.4 )
+( cd opt/kde/lib ; ln -sf liboktetakastencore.so.4.4.0 liboktetakastencore.so.4 )
+( cd opt/kde/lib ; rm -rf liboktetakastencore.so )
+( cd opt/kde/lib ; ln -sf liboktetakastencore.so.4 liboktetakastencore.so )
+( cd opt/kde/lib ; rm -rf liboktetakastengui.so.4 )
+( cd opt/kde/lib ; ln -sf liboktetakastengui.so.4.4.0 liboktetakastengui.so.4 )
+( cd opt/kde/lib ; rm -rf liboktetakastengui.so )
+( cd opt/kde/lib ; ln -sf liboktetakastengui.so.4 liboktetakastengui.so )
+( cd opt/kde/lib ; rm -rf liboktetakastencontrollers.so.4 )
+( cd opt/kde/lib ; ln -sf liboktetakastencontrollers.so.4.4.0 liboktetakastencontrollers.so.4 )
+( cd opt/kde/lib ; rm -rf liboktetakastencontrollers.so )
+( cd opt/kde/lib ; ln -sf liboktetakastencontrollers.so.4 liboktetakastencontrollers.so )
+( cd opt/kde/lib ; rm -rf libsuperkaramba.so.4 )
+( cd opt/kde/lib ; ln -sf libsuperkaramba.so.4.4.0 libsuperkaramba.so.4 )
+( cd opt/kde/lib ; rm -rf libsuperkaramba.so )
+( cd opt/kde/lib ; ln -sf libsuperkaramba.so.4 libsuperkaramba.so )
 ( cd opt/kde/share/doc/HTML/en/ark ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/ark ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/superkaramba ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/superkaramba ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcalc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcalc ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kfloppy ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kfloppy ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kgpg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kgpg ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/ktimer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/ktimer ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kwallet ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kwallet ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/okteta ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/okteta ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/superkaramba ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/superkaramba ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/printer-applet ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/printer-applet ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kdf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kdf ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/blockdevices ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/blockdevices ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kfloppy ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kfloppy ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/ktimer ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/ktimer ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcmlirc ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcmlirc ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcharselect ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcharselect ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/irkick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/irkick ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcmlirc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcmlirc ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/bin ; rm -rf printer-applet )
 ( cd opt/kde/bin ; ln -sf /opt/kde/share/apps/printer-applet/printer-applet.py printer-applet )
-( cd opt/kde/lib ; rm -rf libkdelirc_shared.so )
-( cd opt/kde/lib ; ln -sf libkdelirc_shared.so.1 libkdelirc_shared.so )
-( cd opt/kde/lib ; rm -rf libkdelirc_shared.so.1 )
-( cd opt/kde/lib ; ln -sf libkdelirc_shared.so.1.0.0 libkdelirc_shared.so.1 )
-( cd opt/kde/lib ; rm -rf liboktetagui.so.4 )
-( cd opt/kde/lib ; ln -sf liboktetagui.so.4.3.0 liboktetagui.so.4 )
-( cd opt/kde/lib ; rm -rf libsuperkaramba.so.4 )
-( cd opt/kde/lib ; ln -sf libsuperkaramba.so.4.3.0 libsuperkaramba.so.4 )
-( cd opt/kde/lib ; rm -rf liboktetagui.so )
-( cd opt/kde/lib ; ln -sf liboktetagui.so.4 liboktetagui.so )
-( cd opt/kde/lib ; rm -rf libkerfuffle.so )
-( cd opt/kde/lib ; ln -sf libkerfuffle.so.4 libkerfuffle.so )
-( cd opt/kde/lib ; rm -rf liboktetacore.so.4 )
-( cd opt/kde/lib ; ln -sf liboktetacore.so.4.3.0 liboktetacore.so.4 )
-( cd opt/kde/lib ; rm -rf libsuperkaramba.so )
-( cd opt/kde/lib ; ln -sf libsuperkaramba.so.4 libsuperkaramba.so )
-( cd opt/kde/lib ; rm -rf libkerfuffle.so.4 )
-( cd opt/kde/lib ; ln -sf libkerfuffle.so.4.3.0 libkerfuffle.so.4 )
-( cd opt/kde/lib ; rm -rf liboktetacore.so )
-( cd opt/kde/lib ; ln -sf liboktetacore.so.4 liboktetacore.so )
-#%% begin initialize kdeutils-4.3.5
+#%% begin initialize kdeutils-4.4.5
 if [ -f /opt/kde/bin/plamo_update_kde.sh ]; then
 	/bin/bash /opt/kde/bin/plamo_update_kde.sh
 fi
